rm(list = ls())

options(scipen = 999)

pacman::p_load("dplyr","readr",'lubridate','ggplot2','haven','readxl','purrr',"Formula", 
               'fixest', 'stringr', 'xtable', 'sf', 'geosphere', 'viridis', 'ggstar', 
               'ggmap', 'tidyr')


myThemeStuff <- 
  theme(panel.background = element_rect(fill=NA),
        axis.line = element_line(color = 'black'),
        axis.text = element_text(color = "black", size = 12, family="sans"),
        axis.title = element_text(color = "black", size = 14, family = "sans"),
        legend.text = element_text(color = "black", size = 12, family="sans"), 
        legend.title = element_text(color = "black", size = 14, family="sans")
  )


#restaurant coordinates
coords <- read_dta('data/raw_data/restaurants_gps_ano.dta') %>%
  rename(rest_a_4latitude = a_4latitude, rest_a_4longitude = a_4longitude) %>% 
  mutate(c0_1string = as.factor(c0_1string))

#Have to get API key in Google Maps. Do so as follows. This is free:
#1. Go to the Google Cloud Platform Console (https://console.cloud.google.com/).
#2. Create or select a project.
#3. Click on the hamburger menu in the top left and navigate to "APIs & Services" -> "Library".
#4. In the search bar, type "Maps Static API" and select the appropriate result.
#5. Click "ENABLE".
#After this, you would need to create an API key, which you will use for authenticating your requests from R. Here is how you can do that:
#1. Go back to the Google Cloud Platform Console.
#2. Click on the hamburger menu in the top left and navigate to "APIs & Services" -> "Credentials".
#3. Click "CREATE CREDENTIALS" and select "API key". Your new key will be generated and displayed on the screen.
#4. Click "RESTRICT KEY" and apply necessary restrictions. It's recommended to restrict the API key to prevent misuse.
#Then in R run:
#ggmap::register_google(key = "your_api_key")

#Get satellite basemap
satmap <- get_map(location = c(15.313419, -4.325391), 
                  maptype = 'satellite', zoom = 13, 
                  color = 'bw')


#Buffer by 0.02 degrees
sf::sf_use_s2(FALSE) 

#Create buffer around points so that buffer contains true restaurant location
buf <- st_as_sf(coords, coords = c("rest_a_4longitude", "rest_a_4latitude"), 
                crs = 4326) %>% 
  st_buffer(dist = 0.02)



plot <- ggmap(satmap) + 
  myThemeStuff + 
  scale_color_viridis_d("", option = "C") + 
  geom_sf(data = buf, inherit.aes = FALSE,
              aes(col = c0_1string), fill = NA, linewidth = 2, linetype = 'dashed') + 
  scale_x_continuous("Longitude", 
       expand = c(0, 0)) +   
  scale_y_continuous("Latitude", 
                     breaks = c(-4.31, -4.33, -4.35, -4.37), 
                     labels = c("4.31°S", "4.33°S", "4.35°S", "4.37°S"), 
                     expand = c(0, 0)) +
  theme(legend.position = c(0.2, 0.18), 
        legend.title=element_blank()) + 
  guides(color = guide_legend(override.aes = list(linetype = "solid")))

ggsave(filename = 'output/figures/figure1.pdf', 
       plot, width = 7.4, height = 7.4,  units = 'in')





#As a summary statistic, compute distance from survey to every restaurant
#compare distance to restaurant chosen to average distance to three non-chosen restaurants
#created in make_coupon_data.R
load('data/analysis_data/coupon_data.Rdata')

dat <- select(dat, c0_1string, a_4latitude, a_4longitude) %>% 
  st_as_sf(coords = c("a_4longitude", "a_4latitude"), crs = 4326)

coords <- st_as_sf(coords, coords = c("rest_a_4longitude", "rest_a_4latitude"), 
                   crs = 4326) %>% 
  mutate(c0_1string = as.character(c0_1string))

sf::sf_use_s2(TRUE) 

# Calculate the distance matrix in meters
distance_matrix <- st_distance(dat, coords, by_element = FALSE)

# Convert the distance matrix to a data frame for easier manipulation
distance_df <- as.data.frame(distance_matrix) %>% mutate(row_id = row_number())

# Convert 'coords' to a standard data frame and add an identifier
coords_df <- as.data.frame(coords) %>% mutate(col_id = row_number())

# Reshape the distance dataframe to long format
distance_long <- pivot_longer(distance_df, names_to = "col_id", values_to = "distance_m", -row_id)
# Convert col_id to numeric for matching
distance_long$col_id <- as.numeric(gsub("V", "", distance_long$col_id))

# Join to get c0_1string for each distance
distance_long <- left_join(distance_long, select(coords_df, col_id, c0_1string), by = "col_id")

# Join with 'dat' to get matching c0_1string information
dat_df <- as.data.frame(dat) %>% mutate(row_id = row_number())
final_df <- left_join(distance_long, select(dat_df, row_id, c0_1string), by = "row_id", suffix = c("_coords", "_dat"))

# Identify matching vs. non-matching distances
final_df <- final_df %>%
  mutate(matching = ifelse(c0_1string_coords == c0_1string_dat, "Matching", "Non-matching"))

#average distance to chosen restaurant, using jittered coordinates
filter(final_df, matching == "Matching") %>% 
  summarise(mean(distance_m)) #True average distance using non-jittered coordinates was 223 m

#average distance to chosen restaurant, using jittered coordinates
filter(final_df, matching == "Non-matching") %>% 
  summarise(mean(distance_m)) #True average distance using non-jittered coordinates was 3931 m

group_by(final_df, row_id) %>% 
  slice_min(distance_m) %>% 
  filter(matching == "Matching") %>% nrow() / 
  distinct(final_df, row_id) %>% nrow()
#Proportion using real coordinates was 74% (0.7389706); code was same as above
