rm(list = ls())

pacman::p_load("dplyr","readr",'lubridate','ggplot2','haven','readxl','purrr',"Formula", 
               'fixest', 'stringr', 'xtable', 'viridis')

myThemeStuff <- 
  theme(panel.background = element_rect(fill=NA),
        axis.line = element_line(color = 'black'),
        axis.text = element_text(color = "black", size = 10, family="sans"),
        axis.title = element_text(color = "black", size = 14, family = "sans"),
        legend.text = element_text(color = "black", size = 12, family="sans"), 
        legend.title = element_text(color = "black", size = 14, family="sans")
  )

#created in make_coupon_data.R
load('data/analysis_data/coupon_data.Rdata')

#Extract attributes of variables beginning with D; these are six view of bushmeat questions (60 total)
bushcols <- grep("^d[0-9]", names(dat), value = TRUE)

#6 variables to fill values
fillat <- data.frame(tasty = as.numeric(NA), sustainable = as.numeric(NA),
                     healthy = as.numeric(NA), fresh = as.numeric(NA), 
                     cool = as.numeric(NA), legal = as.numeric(NA))

dat <- bind_cols(dat, fillat)

# Function to check if word is in the text
check_word_in_text <- function(text, word) {
  str_detect(text, fixed(word))
}

for(i in bushcols){
  
  #attributes of this column
  myat <- pull(dat, i) %>% attributes()
  
  #which variable is this
  whichvar <- sapply(1:length(fillat), function(x){
    check_word_in_text(myat$label, names(fillat)[x])
  })
  
  fillvar <- names(fillat)[which(whichvar == TRUE)]
  
  #Which responses to this question indicate an unfavorable view
  whichunf <- grep("disagree", names(myat$labels))
  
  #can now drop attributes
  dat[, i] <- pull(dat, i) %>% as.numeric()
  
  #if question order begins with disagree, reverse order
  if(1 %in% whichunf){
    
    #temporary column to hold values
    dat$holdcol <- dat[, i]
    
    #switch order of values
    dat <- mutate(dat, holdcol = case_when(
      holdcol == 1 ~ 5, 
      holdcol == 2 ~ 4, 
      holdcol == 4 ~ 2, 
      holdcol == 5 ~ 1, 
      holdcol == 3 ~ 3
    ))
    
    #put these values back in original column
    dat[, i] <- dat$holdcol
    
  } #otherwise do nothing; don't need to reverse order
  
  
  #now fill these values in appropriate single column
  dat[which(!is.na(pull(dat, i))), which(names(dat) == fillvar)] <- 
    dat[which(!is.na(pull(dat, i))), i]
  
}

#Clean up
rm(myat, i, whichunf, whichvar, fillvar, bushcols, fillat)

dat <- select(dat, -holdcol)

#E_1_1 agree and E_2_1 disagree connect to origin
dat$origin <- as.numeric(dat$e_1_1)

#reverse order of e_2_1
dat$holdcol <- as.numeric(dat$e_2_1)

#switch order of values
dat <- mutate(dat, holdcol = case_when(
  holdcol == 1 ~ 5, 
  holdcol == 2 ~ 4, 
  holdcol == 4 ~ 2, 
  holdcol == 5 ~ 1, 
  holdcol == 3 ~ 3
))

dat$origin[!is.na(dat$holdcol)] <- dat$holdcol[!is.na(dat$holdcol)]

#Clean up
dat <- select(dat, -holdcol)


#F_1_0 and F_1_0_va2 proud of DRC environment (opinion 0)
dat$proud <- as.numeric(dat$f_1_0)
dat$proud[!is.na(dat$f_1_0_va2)] <- as.numeric(dat$f_1_0_va2[!is.na(dat$f_1_0_va2)])

#treatment group assignment
dat <- mutate(dat, subjects_group = if_else(treated == 1, "T", "C"))

dat$subjects_group <- factor(dat$subjects_group, levels = c("T", "C"))

# Create a named vector for the proud label mapping
proud_labels <- c(
  "1" = "Very Proud",
  "2" = "Somewhat Proud",
  "3" = "Neither",
  "4" = "Somewhat Ashamed",
  "5" = "Very Ashamed"
)


# Create the plot
(proudplot <- ggplot(dat %>% #plot percentage of responses
                      group_by(subjects_group, proud) %>%
                      summarise(count = n()) %>%
                      group_by(subjects_group) %>%
                      mutate(percentage = count / sum(count) * 100) %>%
                      ungroup(), 
                    aes(x = factor(proud, levels = 5:1), y = percentage, fill = subjects_group)) +
  geom_col(position = "dodge") +
  coord_flip() +
  scale_fill_viridis_d(option = "C", begin = 0.1, end = 0.8, direction = 1, 
                       breaks = c("C", "T")) +
  scale_y_continuous(breaks = c(0, 15, 30, 45), labels = c("0%", "15%", "30%", "45%"), 
                     expand = expansion(mult = c(0, 0.1))) +
  scale_x_discrete(labels = proud_labels) +
  myThemeStuff + 
  theme(legend.position = c(0.8, 0.25), 
        legend.title = element_blank(),
        axis.title.x = element_blank(),
        axis.title.y = element_blank(), 
        legend.key.size = unit(0.3, "cm"),
        legend.text = element_text(size = 7), 
        legend.background = element_rect(fill = 'white', color = NA))
  )

ggsave(filename = 'output/figures/figure_2h.pdf',
       plot = proudplot,  height = 1.5, width = 3, units = 'in')


#Other seven variable answers are agreement so can have common labels and function for them
agree_labels <- c(
  "1" = "Strongly Agree",
  "2" = "Somewhat Agree",
  "3" = "Neither",
  "4" = "Somewhat Disagree",
  "5" = "Strongly Disagree"
)



#Function of y-variable, 

plotFun <- function(yvar){

  #rename yvar so can refer to directly
  plotdat <- dat; names(plotdat)[names(plotdat) == yvar] <- 'thevar'
  
  #calculate percentage
  plotdat <- group_by(plotdat, subjects_group, thevar) %>%
    summarise(count = n()) %>%
    group_by(subjects_group) %>%
    mutate(percentage = count / sum(count) * 100) %>%
    ungroup()
  
  
  plot <- ggplot(data = plotdat, aes(x = factor(thevar, levels = 5:1), y = percentage, fill = subjects_group)) +
  geom_col(position = "dodge") +
  coord_flip() +
  scale_fill_viridis_d(option = "C", begin = 0.1, end = 0.8, direction = 1, 
                       breaks = c("C", "T")) +
  scale_y_continuous(breaks = c(0, 15, 30, 45), labels = c("0%", "15%", "30%", "45%"), 
                     expand = expansion(mult = c(0, 0.1))) +
  scale_x_discrete(labels = agree_labels) +
  myThemeStuff + 
  theme(legend.position = c(0.8, 0.25), 
        legend.title = element_blank(),
        axis.title.x = element_blank(),
        axis.title.y = element_blank(), 
        legend.key.size = unit(0.3, "cm"),
        legend.text = element_text(size = 7), 
        legend.background = element_rect(fill = 'white', color = NA))
  
  if(yvar == 'tasty'){
    figname <- 'a'
  }else if(yvar == 'sustainable'){
    figname <- 'b'
  }else if(yvar == 'healthy'){
    figname <- 'c'
  }else if(yvar == 'fresh'){
    figname <- 'd'
  }else if(yvar == 'cool'){
    figname <- 'e'
  }else if(yvar == 'legal'){
    figname <- 'f'
  }else if(yvar == 'origin'){
    figname <- 'g'
  }
  
  ggsave(filename = paste0('output/figures/figure_2', figname, '.pdf'),
        plot = plot,  height = 1.5, width = 3, units = 'in')
  
}

sapply(c("tasty", "sustainable", "healthy", "fresh", "cool", "legal", "origin"), function(x){
           plotFun(x)
         })
