rm(list = ls())

pacman::p_load("dplyr","readr",'lubridate','ggplot2','haven','readxl','purrr',"Formula", 
               'fixest', 'stringr', 'xtable')

#For making tables
formNum <- function(mynum, dig){
  
  roundcoef <- round(mynum, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundcoef))==0){
    roundcoef <- paste0(roundcoef, ".")
  }
  
  #Add an extra zero beyond the decimal point if needed to get same length
  #Only do if does not contain e- or e+ (scientific notation)
  if(grep("e",roundcoef) %>% length() == 0){
    roundcoef <- sapply(seq_len(length(roundcoef)), function(x){
      if(gsub(".*\\.","",roundcoef[x]) %>% nchar() < dig){
        #Needed length
        zerosneeded <- dig - gsub(".*\\.","",roundcoef[x]) %>% nchar()
        roundcoef[x] <- paste0(roundcoef[x],paste0(rep(0,zerosneeded),collapse=""))
      } else{
        roundcoef[x]
      }
    })
  }
  
  #Add commas if necessary
  roundcoef <- prettyNum(roundcoef, ",")
  
  return(roundcoef)
}

#Given se and number of digits to round to, 
#return formatted SE
formSE <- function(se, dig){
  
  #Round
  roundse <- round(se, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundse))==0){
    roundse <- paste0(roundse, ".")
  }
  
  #Add zeros if necessary
  roundse <- sapply(seq_len(length(roundse)), function(x){
    if(gsub(".*\\.","",roundse[x]) %>% nchar() < dig){
      #Needed length (could need one extra zero or two)
      zerosneeded <- dig - gsub(".*\\.","",roundse[x]) %>% nchar()
      roundse[x] <- paste0(roundse[x],paste0(rep(0,zerosneeded),collapse=""))
    } else{
      roundse[x]
    }
  })
  
  #Add commas if necessary
  roundse <- prettyNum(roundse, ",")
  
  #Add parentheses 
  roundse <- paste0("(",roundse,")")
  
  return(roundse)
}

#Given regression object, create formatted vector of coefficients and standard errors
formReg <- function(regobj, dig, depvar, fixedeffects){
  
  vec <- map(names(coefficients(regobj)), function(x){
    
    singlecoef <- formNum(coefficients(regobj)[x], dig)
    singlese <- formSE(se(regobj)[x], dig)
    c(singlecoef, singlese)
    
  }) %>% unlist()
  
  #Append to vec mean of dep var among control group, 
  #percent change treatment coefficient represents relative to this mean
  #and number of obs in regression
  controlmean <- filter(dat, treated == 0) %>% pull(depvar) %>%
    mean()
  #were table and date fixed effects included in the regression?
  indfe <- ifelse(fixedeffects == 1, "Yes", "No")
  
  percentchange <- (coefficients(regobj)["treated"] / controlmean) * 100
  
  vec <- c(vec, indfe,
           regobj$nobs,
           #formNum(controlmean, dig), 
           formNum(percentchange, 2))
  
  return(vec)
}

#Created in merge_survey_with_coupons.do
dat <- read_dta("data/raw_data/survey_with_coupon_data_ano.dta") %>% 
  mutate(random = as.numeric(random)) %>% 
  mutate(treated = if_else(random > 0.5, 1, 0)) %>%#NA if did not eat bushmeat in last 30 days (experiment ended)
  mutate(bushmeat_in_dish = as.numeric(bushmeat_in_dish))

#if bushmeat_in_dish is NA, that means subject did not use coupon. It also means they did not order bushmeat, 
#so fill these obs as 0 and create new used coupon variable
dat <- mutate(dat, takeup = if_else(!is.na(bushmeat_in_dish), 1, 0)) %>% 
  mutate(dat, bushmeat_in_dish = if_else(is.na(bushmeat_in_dish), 0, bushmeat_in_dish))

#month and day of experiment
dat <- mutate(dat, month = month(interview_date), day = day(interview_date))

#First day of experiment was Nov 2, so October obs should be dropped (these may be practice from training)
dat <- filter(dat, month == 11)

#Coupon eligibility period is two weeks
dat <- mutate(dat, days_since_video = difftime(date, interview_date, units = 'days') %>% 
                as.numeric())

#If ordered after two weeks, did not order bushmeat and did not take-up
dat$bushmeat_in_dish[dat$days_since_video < 0 | dat$days_since_video > 14] <- 0
dat$takeup[dat$days_since_video < 0 | dat$days_since_video > 14] <- 0

#obtain values of pre-specified control variables
dat <- rename(dat, age = b_2)

dat <- mutate(dat, male = if_else(b_3 == 0, 1, 0))

dat <- mutate(dat, university = if_else(b_5a == 4, 1, 0))

dat <- rename(dat, educ_years = b_5b)

dat <- rename(dat, salary = b_7a)

dat <- rename(dat, business_owner = b_8a)

dat <- rename(dat, days_bushmeat = bushmeat)

#subject reports eating bushmeat in formal or informal restaurant
dat$restaurant <- 0
dat$restaurant[grep("1", dat$loc)] <- 1
dat$restaurant[grep("2", dat$loc)] <- 1

#Interview date and table fixed effects
dat <- mutate(dat, interview_date_fe = as.factor(interview_date), 
              table_fe = as.factor(enum_2))

save(dat, file = 'data/analysis_data/coupon_data.Rdata')
