rm(list = ls())

pacman::p_load("dplyr","readr",'lubridate','ggplot2','haven','readxl','purrr',"Formula", 
               'fixest', 'stringr','tidyr', 'xtable')

#For making tables
formNum <- function(mynum, dig){
  
  roundcoef <- round(mynum, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundcoef))==0){
    roundcoef <- paste0(roundcoef, ".")
  }
  
  #Add an extra zero beyond the decimal point if needed to get same length
  #Only do if does not contain e- or e+ (scientific notation)
  if(grep("e",roundcoef) %>% length() == 0){
    roundcoef <- sapply(seq_len(length(roundcoef)), function(x){
      if(gsub(".*\\.","",roundcoef[x]) %>% nchar() < dig){
        #Needed length
        zerosneeded <- dig - gsub(".*\\.","",roundcoef[x]) %>% nchar()
        roundcoef[x] <- paste0(roundcoef[x],paste0(rep(0,zerosneeded),collapse=""))
      } else{
        roundcoef[x]
      }
    })
  }
  
  #Add commas if necessary
  roundcoef <- prettyNum(roundcoef, ",")
  
  return(roundcoef)
}

#Given se and number of digits to round to, 
#return formatted SE
formSE <- function(se, dig){
  
  #Round
  roundse <- round(se, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundse))==0){
    roundse <- paste0(roundse, ".")
  }
  
  #Add zeros if necessary
  roundse <- sapply(seq_len(length(roundse)), function(x){
    if(gsub(".*\\.","",roundse[x]) %>% nchar() < dig){
      #Needed length (could need one extra zero or two)
      zerosneeded <- dig - gsub(".*\\.","",roundse[x]) %>% nchar()
      roundse[x] <- paste0(roundse[x],paste0(rep(0,zerosneeded),collapse=""))
    } else{
      roundse[x]
    }
  })
  
  #Add commas if necessary
  roundse <- prettyNum(roundse, ",")
  
  #Add parentheses 
  roundse <- paste0("(",roundse,")")
  
  return(roundse)
}

#Given regression object, create formatted vector of coefficients and standard errors
formReg <- function(regobj, dig){
  
  vec <- map(names(coefficients(regobj)), function(x){
    
    singlecoef <- formNum(coefficients(regobj)[x], dig)
    singlese <- formSE(se(regobj)[x], dig)
    c(singlecoef, singlese)
    
  }) %>% unlist()
  
  vec <- c(vec, 
           regobj$nobs)
  
  return(vec)
}

#one sheet for each restaurant
sheetnames <- excel_sheets("data/raw_data/sales_data_ano.xlsx")

#Read given sheet index and reformat to long
reformFun <- function(sheetind){
  
  onesheet <- read_excel("data/raw_data/sales_data_ano.xlsx", 
                         sheet = sheetnames[sheetind], 
                         skip = 1)
  
  #A few data entry errors where 11/1 entered instead of 12/1
  if(sheetnames[sheetind] == "Restaurant B"){
    
    onesheet$`DATE DU JOUR...2`[23] <- onesheet$`DATE DU JOUR...2`[22] + 60*60*24
    
    onesheet$`DATE DU JOUR...10`[27] <- onesheet$`DATE DU JOUR...10`[26] + 60*60*24
    
    onesheet$`DATE DU JOUR...17`[23] <- onesheet$`DATE DU JOUR...17`[22]  + 60*60*24
    
    #also rename moambe chicken price column to match other sheets
    onesheet <- rename(onesheet, `PRIX UNITAIRE...4` = `PRIX UNITAIRE`, 
                       `PRIX UNITAIRE...12` = `PRIX UNITAIRE (CDF)`)
    
  }else if(sheetnames[sheetind] == "Restaurant D"){
    
    onesheet$`DATE DU JOUR...2`[26] <- onesheet$`DATE DU JOUR...2`[25] + 60*60*24
    
  }
  
  # Select only the relevant columns for Moambe Chicken
  onesheet_chicken <- onesheet %>% 
    select(`DATE DU JOUR...2`, `NOMBRE DE PLAT...3`, `PRIX UNITAIRE...4`) %>% 
    rename(date = `DATE DU JOUR...2`, number_sold = `NOMBRE DE PLAT...3`, price = `PRIX UNITAIRE...4`) %>% 
    mutate(dish = "Moambe Chicken")
  
  # Select and reshape the bushmeat data
  onesheet_bushmeat <- onesheet %>% 
    select(`TYPE DE VIANDE`, `DATE DU JOUR...10`, `NOMBRE DE PLAT...11`, `PRIX UNITAIRE...12`) %>% 
    rename(dish = `TYPE DE VIANDE`, date = `DATE DU JOUR...10`, number_sold = `NOMBRE DE PLAT...11`, price = `PRIX UNITAIRE...12`)
  
  
  #when multiple types of bushmeat sold on same day, calculate total plates sold and weighted average price, where weights are number of 
  #dishes of each type of bushmeat sold
  onesheet_bushmeat <- group_by(onesheet_bushmeat, date) %>% summarise(
    number_sold = sum(number_sold)
  ) %>% ungroup() %>% mutate(dish = 'bushmeat') %>% 
    left_join(
      onesheet_bushmeat %>% mutate(weighted_price = number_sold*price) %>% 
        group_by(date) %>% 
        summarise(price = sum(weighted_price) / sum(number_sold)) %>% 
        ungroup, by = 'date')
  
  # Combine chicken and bushmeat data
  long_format <- rbind(onesheet_chicken, onesheet_bushmeat)
  
  # Arrange the data by date and dish
  long_format <- long_format %>% arrange(date, dish) %>% 
    mutate(restaurant = sheetnames[sheetind]) %>% 
    mutate(date = as.Date(date)) %>% 
    filter(!is.na(date))
  
  if(sheetnames[sheetind] == "Restaurant B"){
    
    #zero bushmeat dishes sold on Nov 9 and Dec 1 so price became NA because of weighted average
    #the price was not missing originally; it is 45000
    long_format$price[long_format$dish == 'bushmeat' & 
                        long_format$date %in% c(as.Date("2023-11-09"), as.Date("2023-12-01"))] <- 45000
    
  }
  
  return(long_format)
}

#Format four restaurant sales data
sales <- map_df(1:4, function(x){
  reformFun(x)
})

#remove space and lower case
sales$dish[sales$dish == "Moambe Chicken"] <- "moambe_chicken"

#Separate bushmeat and chicken columns
price_wide <- sales %>%
  select(-number_sold) %>%
  pivot_wider(names_from = dish, values_from = price, names_prefix = "price_")

# Next, pivot wider for the number_sold column
number_sold_wide <- sales %>%
  select(-price) %>%
  pivot_wider(names_from = dish, values_from = number_sold, names_prefix = "number_sold_")

# Joining the two wide data frames
sales <- left_join(price_wide, number_sold_wide, by = c("date", "restaurant"))

#Experiment began on Nov 9, 2023
#Pre-specified that would control for number of bushmeat plates sold in week before experiment, 
#so those sold between Nov 2 and 8
sales <- left_join(sales, 
                   filter(sales, date >= as.Date("2023-11-02") & date <= as.Date("2023-11-08")) %>% 
                     group_by(restaurant) %>% 
                     summarise(Q0 = sum(number_sold_bushmeat, na.rm = TRUE)) %>% ungroup(), 
                   by = 'restaurant')

#Drop pre-experiment data
sales <- filter(sales, date >= as.Date("2023-11-09"))

#These sample menu data are from data/raw_data/restaurants_menu.xlsx
P0df <- 
  data.frame(restaurant = c("Restaurant B", "Restaurant C",
                            "Restaurant A", "Restaurant D"),
             P0 = c(mean(c(65000, 35000, 35000, 35000, 35000, 35000, 35000, 50000, 
                           40000, 35000, 30000, 20000, 35000, 35000, 35000, 35000, 
                           45000, 45000, 40000, 35000, 35000, 35000, 35000, 35000, 
                           35000, 45000, 35000, 20000, 40000, 35000, 35000, 45000, 45000)), 
                    mean(rep(20000, 19)),
                    mean(rep(17000, 28)),
                    mean(c(15000, 15000, 15000, 20000, 20000, 15000, 15000, 15000,
                           20000, 20000, 20000, 25000, 25000, 25000, 17000, 17000, 
                           17500, 15000, 25000, 25000, 15000, 20000))
             )
  )

#As a descriptive statistic for the main text of the paper, what is the average price of bushmeat dishes
#compared to non-bushmeat dishes, in the two restaurants with differentiated pricing?
#Using raw_data/restaurants_menu.xlsx
#At Restaurant B, Ngulu, Antilope, and Porc Sauvage are bushmeat, with average price of 
#41,667 CDF, compared to average non-bushmeat price of remaining 30 dishes of 30,000 CDF
#So 39% more expensive
#At Restaurant D, Ngulu, Antilope, Simbiliki, Sombo, and Mpakasa are bushmeat, with average price of 
#24,000 CDF, compared to average non-bushmeat price of remaining 17 dishes of 17,441 CDF
#So bushmeat is 38% more expensive

#join onto sales
sales <- left_join(sales, P0df, by = 'restaurant')

#treated days from treat_restaurants.R
sales <- left_join(sales, 
                   data.frame(
                     restaurant = c(
                       "Restaurant B", 
                       "Restaurant D", 
                       "Restaurant C", 
                       "Restaurant D", 
                       "Restaurant A", 
                       "Restaurant D", 
                       "Restaurant A", 
                       "Restaurant D", 
                       "Restaurant C", 
                       "Restaurant C", 
                       "Restaurant A"
                     ), 
                     date = c(
                       "2023-11-09", 
                       "2023-11-13", 
                       "2023-11-13", 
                       "2023-11-14", 
                       "2023-11-14", 
                       "2023-11-15", 
                       "2023-11-15", 
                       "2023-11-16", 
                       "2023-11-16", 
                       "2023-11-17", 
                       "2023-11-17"
                     )
                   ) %>% mutate(date = as.Date(date), treated = 1), 
                   by = c("restaurant","date")
)

#if treated missing it was not treated
sales$treated[is.na(sales$treated)] <- 0

#on treated days, moambe chicken price was lowered by CDF 5000. 
#this is reflected in raw data by highlighting in excel file, but the recorded price was not lowered
sales$price_moambe_chicken[sales$treated == 1] <- sales$price_moambe_chicken[sales$treated == 1] - 5000

#P0 in thousands of CDF so numbers visible in table
sales <- mutate(sales, P0 = P0 / 1000)

save(sales, file = 'data/analysis_data/sales_data.Rdata')

