* initialize Stata
clear all
set more off
set mem 100m

* initialize workflow-specific parameters
*	Set overwrite_old_data to 1 if you use the review and correction
*	workflow and allow un-approving of submissions. If you do this,
*	incoming data will overwrite old data, so you won't want to make
*	changes to data in your local .dta file (such changes can be
*	overwritten with each new import).
local overwrite_old_data 0

**Enter the file path to the project folder 
global projectfolder "path_to_folder"

**change director
cd "$projectfolder"
  
*Step 1:import the coupon id dataset into Stata environment
import excel "${projectfolder}/raw_data/coupon_data_ano.xlsx", firstrow clear
compress

* initialize form-specific parameters
local csvfile "${projectfolder}\raw_data\confidential\survey_data_confidential.csv"

local dtafile "${projectfolder}\raw_data\survey_data_ano.dta"

local corrfile "${projectfolder}\raw_data\internal\survey_data_confidential_corrections.csv"
local note_fields1 ""
local text_fields1 "deviceid username devicephonenum a_3 my_seed random1 random2 version1 version2_1 version2_2 version2_3 version2_4 version2_5 b_1 b_4 qualify loc random c0_1string coupon_id_gen observation instanceid"
local date_fields1 "interview_date"
local datetime_fields1 "submissiondate starttime endtime"

disp
disp "Starting import of: `csvfile'"
disp

* import data from primary .csv file
insheet using "`csvfile'", names clear

* drop extra table-list columns
cap drop reserved_name_for_field_*
cap drop generated_table_list_lab*

* continue only if there's at least one row of data to import
if _N>0 {
	* drop note fields (since they don't contain any real data)
	forvalues i = 1/100 {
		if "`note_fields`i''" ~= "" {
			drop `note_fields`i''
		}
	}
	
	* format date and date/time fields
	forvalues i = 1/100 {
		if "`datetime_fields`i''" ~= "" {
			foreach dtvarlist in `datetime_fields`i'' {
				cap unab dtvarlist : `dtvarlist'
				if _rc==0 {
					foreach dtvar in `dtvarlist' {
						tempvar tempdtvar
						rename `dtvar' `tempdtvar'
						gen double `dtvar'=.
						cap replace `dtvar'=clock(`tempdtvar',"DMYhms",2025)
						* automatically try without seconds, just in case
						cap replace `dtvar'=clock(`tempdtvar',"DMYhm",2025) if `dtvar'==. & `tempdtvar'~=""
						format %tc `dtvar'
						drop `tempdtvar'
					}
				}
			}
		}
		if "`date_fields`i''" ~= "" {
			foreach dtvarlist in `date_fields`i'' {
				cap unab dtvarlist : `dtvarlist'
				if _rc==0 {
					foreach dtvar in `dtvarlist' {
						tempvar tempdtvar
						rename `dtvar' `tempdtvar'
						gen double `dtvar'=.
						cap replace `dtvar'=date(`tempdtvar',"DMY",2025)
						format %td `dtvar'
						drop `tempdtvar'
					}
				}
			}
		}
	}

	* ensure that text fields are always imported as strings (with "" for missing values)
	* (note that we treat "calculate" fields as text; you can destring later if you wish)
	tempvar ismissingvar
	quietly: gen `ismissingvar'=.
	forvalues i = 1/100 {
		if "`text_fields`i''" ~= "" {
			foreach svarlist in `text_fields`i'' {
				cap unab svarlist : `svarlist'
				if _rc==0 {
					foreach stringvar in `svarlist' {
						quietly: replace `ismissingvar'=.
						quietly: cap replace `ismissingvar'=1 if `stringvar'==.
						cap tostring `stringvar', format(%100.0g) replace
						cap replace `stringvar'="" if `ismissingvar'==1
					}
				}
			}
		}
	}
	quietly: drop `ismissingvar'


	* consolidate unique ID into "key" variable
	replace key=instanceid if key==""
	drop instanceid


	* label variables
	label variable key "Unique submission ID"
	cap label variable submissiondate "Date/time submitted"
	cap label variable formdef_version "Form version used on device"
	cap label variable review_status "Review status"
	cap label variable review_comments "Comments made during review"
	cap label variable review_corrections "Corrections made during review"


	label variable enum_2 "What is the name of the enumerator?"
	note enum_2: "What is the name of the enumerator?"
	label define enum_2 1 "Nzovuanga Embete Arnold" 2 "MOPOLO MONGENGO FISTON MULLER" 3 "BADICINYI KABASELE." 4 "Naomie PELENGE MUYA"
	label values enum_2 enum_2

	label variable enum_3 "What is the name of the supervisor?"
	note enum_3: "What is the name of the supervisor?"
	label define enum_3 1 "Milamba Seba Naomie" 2 "Honoré KABONGO"
	label values enum_3 enum_3

	label variable a_3 "What is the name of the neighborhood, street or block in which the table is loca"
	note a_3: "What is the name of the neighborhood, street or block in which the table is located?"

	label variable a5 "What language would you like the interview to be conducted?"
	note a5: "What language would you like the interview to be conducted?"
	label define a5 1 "French" 2 "Swahili" 3 "Lingala"
	label values a5 a5

	label variable consent "CONSENT We realize your time is valuable and the researchers and we would be ver"
	note consent: "CONSENT We realize your time is valuable and the researchers and we would be very grateful if you chose to participate in our study. Do you agree to participate in this research study?"
	label define consent 1 "Yes" 0 "No"
	label values consent consent

	label variable b_1 "What are your first and last names?"
	note b_1: "What are your first and last names?"

	label variable b_2 "What is your age (in years)?"
	note b_2: "What is your age (in years)?"

	label variable b_3 "What is your gender?"
	note b_3: "What is your gender?"
	label define b_3 0 "Male" 1 "Female"
	label values b_3 b_3

	label variable b_4 "What is your phone number?"
	note b_4: "What is your phone number?"

	label variable b_5a "What is the highest educational level level that you have attained?"
	note b_5a: "What is the highest educational level level that you have attained?"
	label define b_5a 0 "Does not know" 1 "No education" 2 "Primary school" 3 "Secondary school" 4 "University"
	label values b_5a b_5a

	label variable b_5b "How many years of formal education have you completed?"
	note b_5b: "How many years of formal education have you completed?"

	label variable b_7a "Were you employed for pay by another individual, company or organization in the "
	note b_7a: "Were you employed for pay by another individual, company or organization in the last 7 days?"
	label define b_7a 1 "Yes" 0 "No"
	label values b_7a b_7a

	label variable b_7b "How much did you get paid at this job?"
	note b_7b: "How much did you get paid at this job?"

	label variable b_7c "What was the frequency of the salary you received from this job?"
	note b_7c: "What was the frequency of the salary you received from this job?"
	label define b_7c 1 "Daily" 2 "Weekly" 3 "Monthly" 4 "Quarterly" 5 "Yearly"
	label values b_7c b_7c

	label variable b_8a "Have you worked as an owner of an establishment for pay in the last 7 days?"
	note b_8a: "Have you worked as an owner of an establishment for pay in the last 7 days?"
	label define b_8a 1 "Yes" 0 "No"
	label values b_8a b_8a

	label variable b_8b "What was the turnover of the establishment after paying all expenses, including "
	note b_8b: "What was the turnover of the establishment after paying all expenses, including employee salaries, but not counting the income you paid yourself. In other words, what is the net profits of your establishment?'"

	label variable b_8c "What was the frequency of the profits you made from this job?"
	note b_8c: "What was the frequency of the profits you made from this job?"
	label define b_8c 1 "Daily" 2 "Weekly" 3 "Monthly" 4 "Quarterly" 5 "Yearly"
	label values b_8c b_8c

	label variable bushmeat "For how many days have you eaten bushmeat in the last 30 days?"
	note bushmeat: "For how many days have you eaten bushmeat in the last 30 days?"

	label variable loc "Where do you usually eat bushmeat?"
	note loc: "Where do you usually eat bushmeat?"

	label variable c_1a "TO ENUMERATOR: Please show this video to participant."
	note c_1a: "TO ENUMERATOR: Please show this video to participant."
	label define c_1a 1 "Video"
	label values c_1a c_1a

	label variable c_1b "TO ENUMERATOR: Please show this video to participant."
	note c_1b: "TO ENUMERATOR: Please show this video to participant."
	label define c_1b 1 "Video"
	label values c_1b c_1b

	label variable seen_video "Think deeply, have you ever seen/watch the video I just played to you before?"
	note seen_video: "Think deeply, have you ever seen/watch the video I just played to you before?"
	label define seen_video 1 "Yes" 0 "No"
	label values seen_video seen_video

	label variable c0_1 "Which restaurant would you like a coupon to?"
	note c0_1: "Which restaurant would you like a coupon to?"
	label define c0_1 1 "Restaurant Chez Françoise" 2 "Restaurant La grâce" 3 "Resto-Bar" 4 "Restaurant Le Maxime"
	label values c0_1 c0_1

	label variable d1_1_1 "Do you agree or disagree that bushmeat is tasty?"
	note d1_1_1: "Do you agree or disagree that bushmeat is tasty?"
	label define d1_1_1 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d1_1_1 d1_1_1

	label variable d1_1_2 "Do you agree or disagree that bushmeat is sustainable?"
	note d1_1_2: "Do you agree or disagree that bushmeat is sustainable?"
	label define d1_1_2 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d1_1_2 d1_1_2

	label variable d1_1_3 "Do you agree or disagree that bushmeat is healthy?"
	note d1_1_3: "Do you agree or disagree that bushmeat is healthy?"
	label define d1_1_3 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d1_1_3 d1_1_3

	label variable d1_1_4 "Do you agree or disagree that bushmeat is fresh?"
	note d1_1_4: "Do you agree or disagree that bushmeat is fresh?"
	label define d1_1_4 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d1_1_4 d1_1_4

	label variable d1_1_5 "Do you agree or disagree that bushmeat is cool?"
	note d1_1_5: "Do you agree or disagree that bushmeat is cool?"
	label define d1_1_5 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d1_1_5 d1_1_5

	label variable d1_1_6 "Do you agree or disagree that bushmeat is legal?"
	note d1_1_6: "Do you agree or disagree that bushmeat is legal?"
	label define d1_1_6 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d1_1_6 d1_1_6

	label variable d2_1_1 "Do you agree or disagree that bushmeat is fresh?"
	note d2_1_1: "Do you agree or disagree that bushmeat is fresh?"
	label define d2_1_1 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d2_1_1 d2_1_1

	label variable d2_1_2 "Do you agree or disagree that bushmeat is legal?"
	note d2_1_2: "Do you agree or disagree that bushmeat is legal?"
	label define d2_1_2 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d2_1_2 d2_1_2

	label variable d2_1_3 "Do you agree or disagree that bushmeat is healthy?"
	note d2_1_3: "Do you agree or disagree that bushmeat is healthy?"
	label define d2_1_3 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d2_1_3 d2_1_3

	label variable d2_1_4 "Do you agree or disagree that bushmeat is tasty?"
	note d2_1_4: "Do you agree or disagree that bushmeat is tasty?"
	label define d2_1_4 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d2_1_4 d2_1_4

	label variable d2_1_5 "Do you agree or disagree that bushmeat is cool?"
	note d2_1_5: "Do you agree or disagree that bushmeat is cool?"
	label define d2_1_5 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d2_1_5 d2_1_5

	label variable d2_1_6 "Do you agree or disagree that bushmeat is sustainable?"
	note d2_1_6: "Do you agree or disagree that bushmeat is sustainable?"
	label define d2_1_6 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d2_1_6 d2_1_6

	label variable d3_1_1 "Do you agree or disagree that bushmeat is sustainable?"
	note d3_1_1: "Do you agree or disagree that bushmeat is sustainable?"
	label define d3_1_1 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d3_1_1 d3_1_1

	label variable d3_1_2 "Do you agree or disagree that bushmeat is fresh?"
	note d3_1_2: "Do you agree or disagree that bushmeat is fresh?"
	label define d3_1_2 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d3_1_2 d3_1_2

	label variable d3_1_3 "Do you agree or disagree that bushmeat is tasty?"
	note d3_1_3: "Do you agree or disagree that bushmeat is tasty?"
	label define d3_1_3 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d3_1_3 d3_1_3

	label variable d3_1_4 "Do you agree or disagree that bushmeat is cool?"
	note d3_1_4: "Do you agree or disagree that bushmeat is cool?"
	label define d3_1_4 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d3_1_4 d3_1_4

	label variable d3_1_5 "Do you agree or disagree that bushmeat is legal?"
	note d3_1_5: "Do you agree or disagree that bushmeat is legal?"
	label define d3_1_5 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d3_1_5 d3_1_5

	label variable d3_1_6 "Do you agree or disagree that bushmeat is healthy?"
	note d3_1_6: "Do you agree or disagree that bushmeat is healthy?"
	label define d3_1_6 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d3_1_6 d3_1_6

	label variable d4_1_1 "Do you agree or disagree that bushmeat is legal?"
	note d4_1_1: "Do you agree or disagree that bushmeat is legal?"
	label define d4_1_1 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d4_1_1 d4_1_1

	label variable d4_1_2 "Do you agree or disagree that bushmeat is fresh?"
	note d4_1_2: "Do you agree or disagree that bushmeat is fresh?"
	label define d4_1_2 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d4_1_2 d4_1_2

	label variable d4_1_3 "Do you agree or disagree that bushmeat is cool?"
	note d4_1_3: "Do you agree or disagree that bushmeat is cool?"
	label define d4_1_3 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d4_1_3 d4_1_3

	label variable d4_1_4 "Do you agree or disagree that bushmeat is healthy?"
	note d4_1_4: "Do you agree or disagree that bushmeat is healthy?"
	label define d4_1_4 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d4_1_4 d4_1_4

	label variable d4_1_5 "Do you agree or disagree that bushmeat is sustainable?"
	note d4_1_5: "Do you agree or disagree that bushmeat is sustainable?"
	label define d4_1_5 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d4_1_5 d4_1_5

	label variable d4_1_6 "Do you agree or disagree that bushmeat is tasty?"
	note d4_1_6: "Do you agree or disagree that bushmeat is tasty?"
	label define d4_1_6 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d4_1_6 d4_1_6

	label variable d5_1_1 "Do you agree or disagree that bushmeat is cool?"
	note d5_1_1: "Do you agree or disagree that bushmeat is cool?"
	label define d5_1_1 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d5_1_1 d5_1_1

	label variable d5_1_2 "Do you agree or disagree that bushmeat is legal?"
	note d5_1_2: "Do you agree or disagree that bushmeat is legal?"
	label define d5_1_2 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d5_1_2 d5_1_2

	label variable d5_1_3 "Do you agree or disagree that bushmeat is fresh?"
	note d5_1_3: "Do you agree or disagree that bushmeat is fresh?"
	label define d5_1_3 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d5_1_3 d5_1_3

	label variable d5_1_4 "Do you agree or disagree that bushmeat is tasty?"
	note d5_1_4: "Do you agree or disagree that bushmeat is tasty?"
	label define d5_1_4 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d5_1_4 d5_1_4

	label variable d5_1_5 "Do you agree or disagree that bushmeat is sustainable?"
	note d5_1_5: "Do you agree or disagree that bushmeat is sustainable?"
	label define d5_1_5 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d5_1_5 d5_1_5

	label variable d5_1_6 "Do you agree or disagree that bushmeat is healthy?"
	note d5_1_6: "Do you agree or disagree that bushmeat is healthy?"
	label define d5_1_6 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values d5_1_6 d5_1_6

	label variable e_1_1 "Do you agree or disagree that bushmeat connects you to your place of origin?"
	note e_1_1: "Do you agree or disagree that bushmeat connects you to your place of origin?"
	label define e_1_1 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values e_1_1 e_1_1

	label variable e_1_2 "Is it common or uncommon for your friends to eat bushmeat?"
	note e_1_2: "Is it common or uncommon for your friends to eat bushmeat?"
	label define e_1_2 1 "Very common" 2 "Somewhat common" 3 "Neither common nor uncommon" 4 "Somewhat uncommon" 5 "Very uncommon"
	label values e_1_2 e_1_2

	label variable e_1_3 "Is it common or uncommon for your family to eat bushmeat?"
	note e_1_3: "Is it common or uncommon for your family to eat bushmeat?"
	label define e_1_3 1 "Very common" 2 "Somewhat common" 3 "Neither common nor uncommon" 4 "Somewhat uncommon" 5 "Very uncommon"
	label values e_1_3 e_1_3

	label variable e_1_4 "Is it common or uncommon for your colleagues to eat bushmeat?"
	note e_1_4: "Is it common or uncommon for your colleagues to eat bushmeat?"
	label define e_1_4 1 "Very common" 2 "Somewhat common" 3 "Neither common nor uncommon" 4 "Somewhat uncommon" 5 "Very uncommon"
	label values e_1_4 e_1_4

	label variable f_1_0 "Are you proud of the environment of the Democratic Republic of Congo?"
	note f_1_0: "Are you proud of the environment of the Democratic Republic of Congo?"
	label define f_1_0 1 "Very proud" 2 "Somewhat proud" 3 "Neither proud nor ashamed" 4 "Somewhat ashamed/embarassed" 5 "Very ashamed/embarassed"
	label values f_1_0 f_1_0

	label variable f_1_1 "It is sometimes hard for me to go on with my work if I am not encouraged."
	note f_1_1: "It is sometimes hard for me to go on with my work if I am not encouraged."
	label define f_1_1 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values f_1_1 f_1_1

	label variable f_1_2 "I sometimes feel resentful when I don't get my way."
	note f_1_2: "I sometimes feel resentful when I don't get my way."
	label define f_1_2 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values f_1_2 f_1_2

	label variable f_1_3 "On a few occasions, I have given up doing something because I thought too little"
	note f_1_3: "On a few occasions, I have given up doing something because I thought too little of my ability."
	label define f_1_3 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values f_1_3 f_1_3

	label variable f_1_4 "There have been many times whe I felt like rebelling agaisnt people in authority"
	note f_1_4: "There have been many times whe I felt like rebelling agaisnt people in authority even though I knew they were right."
	label define f_1_4 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values f_1_4 f_1_4

	label variable f_1_5 "No matter who I am talking to, I am always a good listener."
	note f_1_5: "No matter who I am talking to, I am always a good listener."
	label define f_1_5 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values f_1_5 f_1_5

	label variable f_1_6 "There have been occasions when I took advantage of someone."
	note f_1_6: "There have been occasions when I took advantage of someone."
	label define f_1_6 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values f_1_6 f_1_6

	label variable f_1_7 "I am always willing to admit it when I make a mistake."
	note f_1_7: "I am always willing to admit it when I make a mistake."
	label define f_1_7 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values f_1_7 f_1_7

	label variable f_1_8 "I sometimes try to get even rather than forgive and forget."
	note f_1_8: "I sometimes try to get even rather than forgive and forget."
	label define f_1_8 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values f_1_8 f_1_8

	label variable f_1_9 "I am always courteous, even to people who are disagreeable."
	note f_1_9: "I am always courteous, even to people who are disagreeable."
	label define f_1_9 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values f_1_9 f_1_9

	label variable f_1_10 "I have never been irked when people expressed ideas very different from my own."
	note f_1_10: "I have never been irked when people expressed ideas very different from my own."
	label define f_1_10 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values f_1_10 f_1_10

	label variable f_1_11 "There have been times when I was quite jealous of the good fortune of others."
	note f_1_11: "There have been times when I was quite jealous of the good fortune of others."
	label define f_1_11 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values f_1_11 f_1_11

	label variable f_1_12 "I am sometimes irritated by people who ask favors of me."
	note f_1_12: "I am sometimes irritated by people who ask favors of me."
	label define f_1_12 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values f_1_12 f_1_12

	label variable f_1_13 "I have deliberately said something that hurt someone's feelings."
	note f_1_13: "I have deliberately said something that hurt someone's feelings."
	label define f_1_13 1 "Strongly agree" 2 "Somewhat agree" 3 "Neither agree nor disagree" 4 "Somewhat disagree" 5 "Strongly disagree"
	label values f_1_13 f_1_13

	label variable d1_2_1 "Do you disagree or agree that bushmeat is tasty?"
	note d1_2_1: "Do you disagree or agree that bushmeat is tasty?"
	label define d1_2_1 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d1_2_1 d1_2_1

	label variable d1_2_2 "Do you disagree or agree that bushmeat is sustainable?"
	note d1_2_2: "Do you disagree or agree that bushmeat is sustainable?"
	label define d1_2_2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d1_2_2 d1_2_2

	label variable d1_2_3 "Do you disagree or agree that bushmeat is healthy?"
	note d1_2_3: "Do you disagree or agree that bushmeat is healthy?"
	label define d1_2_3 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d1_2_3 d1_2_3

	label variable d1_2_4 "Do you disagree or agree that bushmeat is fresh?"
	note d1_2_4: "Do you disagree or agree that bushmeat is fresh?"
	label define d1_2_4 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d1_2_4 d1_2_4

	label variable d1_2_5 "Do you disagree or agree that bushmeat is cool?"
	note d1_2_5: "Do you disagree or agree that bushmeat is cool?"
	label define d1_2_5 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d1_2_5 d1_2_5

	label variable d1_2_6 "Do you disagree or agree that bushmeat is legal?"
	note d1_2_6: "Do you disagree or agree that bushmeat is legal?"
	label define d1_2_6 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d1_2_6 d1_2_6

	label variable d2_2_1 "Do you disagree or agree that bushmeat is fresh?"
	note d2_2_1: "Do you disagree or agree that bushmeat is fresh?"
	label define d2_2_1 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d2_2_1 d2_2_1

	label variable d2_2_2 "Do you disagree or agree that bushmeat is legal?"
	note d2_2_2: "Do you disagree or agree that bushmeat is legal?"
	label define d2_2_2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d2_2_2 d2_2_2

	label variable d2_2_3 "Do you disagree or agree that bushmeat is healthy?"
	note d2_2_3: "Do you disagree or agree that bushmeat is healthy?"
	label define d2_2_3 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d2_2_3 d2_2_3

	label variable d2_2_4 "Do you disagree or agree that bushmeat is tasty?"
	note d2_2_4: "Do you disagree or agree that bushmeat is tasty?"
	label define d2_2_4 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d2_2_4 d2_2_4

	label variable d2_2_5 "Do you disagree or agree that bushmeat is cool?"
	note d2_2_5: "Do you disagree or agree that bushmeat is cool?"
	label define d2_2_5 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d2_2_5 d2_2_5

	label variable d2_2_6 "Do you disagree or agree that bushmeat is sustainable?"
	note d2_2_6: "Do you disagree or agree that bushmeat is sustainable?"
	label define d2_2_6 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d2_2_6 d2_2_6

	label variable d3_2_1 "Do you disagree or agree that bushmeat is sustainable?"
	note d3_2_1: "Do you disagree or agree that bushmeat is sustainable?"
	label define d3_2_1 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d3_2_1 d3_2_1

	label variable d3_2_2 "Do you disagree or agree that bushmeat is fresh?"
	note d3_2_2: "Do you disagree or agree that bushmeat is fresh?"
	label define d3_2_2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d3_2_2 d3_2_2

	label variable d3_2_3 "Do you disagree or agree that bushmeat is tasty?"
	note d3_2_3: "Do you disagree or agree that bushmeat is tasty?"
	label define d3_2_3 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d3_2_3 d3_2_3

	label variable d3_2_4 "Do you disagree or agree that bushmeat is cool?"
	note d3_2_4: "Do you disagree or agree that bushmeat is cool?"
	label define d3_2_4 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d3_2_4 d3_2_4

	label variable d3_2_5 "Do you disagree or agree that bushmeat is legal?"
	note d3_2_5: "Do you disagree or agree that bushmeat is legal?"
	label define d3_2_5 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d3_2_5 d3_2_5

	label variable d3_2_6 "Do you disagree or agree that bushmeat is healthy?"
	note d3_2_6: "Do you disagree or agree that bushmeat is healthy?"
	label define d3_2_6 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d3_2_6 d3_2_6

	label variable d4_2_1 "Do you disagree or agree that bushmeat is legal?"
	note d4_2_1: "Do you disagree or agree that bushmeat is legal?"
	label define d4_2_1 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d4_2_1 d4_2_1

	label variable d4_2_2 "Do you disagree or agree that bushmeat is fresh?"
	note d4_2_2: "Do you disagree or agree that bushmeat is fresh?"
	label define d4_2_2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d4_2_2 d4_2_2

	label variable d4_2_3 "Do you disagree or agree that bushmeat is cool?"
	note d4_2_3: "Do you disagree or agree that bushmeat is cool?"
	label define d4_2_3 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d4_2_3 d4_2_3

	label variable d4_2_4 "Do you disagree or agree that bushmeat is healthy?"
	note d4_2_4: "Do you disagree or agree that bushmeat is healthy?"
	label define d4_2_4 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d4_2_4 d4_2_4

	label variable d4_2_5 "Do you disagree or agree that bushmeat is sustainable?"
	note d4_2_5: "Do you disagree or agree that bushmeat is sustainable?"
	label define d4_2_5 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d4_2_5 d4_2_5

	label variable d4_2_6 "Do you disagree or agree that bushmeat is tasty?"
	note d4_2_6: "Do you disagree or agree that bushmeat is tasty?"
	label define d4_2_6 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d4_2_6 d4_2_6

	label variable d5_2_1 "Do you disagree or agree that bushmeat is cool?"
	note d5_2_1: "Do you disagree or agree that bushmeat is cool?"
	label define d5_2_1 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d5_2_1 d5_2_1

	label variable d5_2_2 "Do you disagree or agree that bushmeat is legal?"
	note d5_2_2: "Do you disagree or agree that bushmeat is legal?"
	label define d5_2_2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d5_2_2 d5_2_2

	label variable d5_2_3 "Do you disagree or agree that bushmeat is fresh?"
	note d5_2_3: "Do you disagree or agree that bushmeat is fresh?"
	label define d5_2_3 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d5_2_3 d5_2_3

	label variable d5_2_4 "Do you disagree or agree that bushmeat is tasty?"
	note d5_2_4: "Do you disagree or agree that bushmeat is tasty?"
	label define d5_2_4 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d5_2_4 d5_2_4

	label variable d5_2_5 "Do you disagree or agree that bushmeat is sustainable?"
	note d5_2_5: "Do you disagree or agree that bushmeat is sustainable?"
	label define d5_2_5 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d5_2_5 d5_2_5

	label variable d5_2_6 "Do you disagree or agree that bushmeat is healthy?"
	note d5_2_6: "Do you disagree or agree that bushmeat is healthy?"
	label define d5_2_6 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values d5_2_6 d5_2_6

	label variable e_2_1 "Do you disagree or agree that bushmeat connects you to your place of origin?"
	note e_2_1: "Do you disagree or agree that bushmeat connects you to your place of origin?"
	label define e_2_1 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values e_2_1 e_2_1

	label variable e_2_2 "Is it uncommon or common for your friends to eat bushmeat?"
	note e_2_2: "Is it uncommon or common for your friends to eat bushmeat?"
	label define e_2_2 1 "Very uncommon" 2 "Somewhat uncommon" 3 "Neither common nor uncommon" 4 "Somewhat common" 5 "Very common"
	label values e_2_2 e_2_2

	label variable e_2_3 "Is it uncommon or common for your family to eat bushmeat?"
	note e_2_3: "Is it uncommon or common for your family to eat bushmeat?"
	label define e_2_3 1 "Very uncommon" 2 "Somewhat uncommon" 3 "Neither common nor uncommon" 4 "Somewhat common" 5 "Very common"
	label values e_2_3 e_2_3

	label variable e_2_4 "Is it uncommon or common for your colleagues to eat bushmeat?"
	note e_2_4: "Is it uncommon or common for your colleagues to eat bushmeat?"
	label define e_2_4 1 "Very uncommon" 2 "Somewhat uncommon" 3 "Neither common nor uncommon" 4 "Somewhat common" 5 "Very common"
	label values e_2_4 e_2_4

	label variable f_1_0_va2 "Are you proud of the environment of the Democratic Republic of Congo?"
	note f_1_0_va2: "Are you proud of the environment of the Democratic Republic of Congo?"
	label define f_1_0_va2 1 "Very proud" 2 "Somewhat proud" 3 "Neither proud nor ashamed" 4 "Somewhat ashamed/embarassed" 5 "Very ashamed/embarassed"
	label values f_1_0_va2 f_1_0_va2

	label variable f_2_1_va2 "It is sometimes hard for me to go on with my work if I am not encouraged."
	note f_2_1_va2: "It is sometimes hard for me to go on with my work if I am not encouraged."
	label define f_2_1_va2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values f_2_1_va2 f_2_1_va2

	label variable f_2_2_va2 "I sometimes feel resentful when I don't get my way."
	note f_2_2_va2: "I sometimes feel resentful when I don't get my way."
	label define f_2_2_va2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values f_2_2_va2 f_2_2_va2

	label variable f_2_3_va2 "On a few occasions, I have given up doing something because I thought too little"
	note f_2_3_va2: "On a few occasions, I have given up doing something because I thought too little of my ability."
	label define f_2_3_va2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values f_2_3_va2 f_2_3_va2

	label variable f_2_4_va2 "There have been many times whe I felt like rebelling agaisnt people in authority"
	note f_2_4_va2: "There have been many times whe I felt like rebelling agaisnt people in authority even though I knew they were right."
	label define f_2_4_va2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values f_2_4_va2 f_2_4_va2

	label variable f_2_5_va2 "No matter who I am talking to, I am always a good listener."
	note f_2_5_va2: "No matter who I am talking to, I am always a good listener."
	label define f_2_5_va2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values f_2_5_va2 f_2_5_va2

	label variable f_2_6_va2 "There have been occasions when I took advantage of someone."
	note f_2_6_va2: "There have been occasions when I took advantage of someone."
	label define f_2_6_va2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values f_2_6_va2 f_2_6_va2

	label variable f_2_7_va2 "I am always willing to admit it when I make a mistake."
	note f_2_7_va2: "I am always willing to admit it when I make a mistake."
	label define f_2_7_va2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values f_2_7_va2 f_2_7_va2

	label variable f_2_8_va2 "I sometimes try to get even rather than forgive and forget."
	note f_2_8_va2: "I sometimes try to get even rather than forgive and forget."
	label define f_2_8_va2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values f_2_8_va2 f_2_8_va2

	label variable f_2_9_va2 "I am always courteous, even to people who are disagreeable."
	note f_2_9_va2: "I am always courteous, even to people who are disagreeable."
	label define f_2_9_va2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values f_2_9_va2 f_2_9_va2

	label variable f_2_10_va2 "I have never been irked when people expressed ideas very different from my own."
	note f_2_10_va2: "I have never been irked when people expressed ideas very different from my own."
	label define f_2_10_va2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values f_2_10_va2 f_2_10_va2

	label variable f_2_11_va2 "There have been times when I was quite jealous of the good fortune of others."
	note f_2_11_va2: "There have been times when I was quite jealous of the good fortune of others."
	label define f_2_11_va2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values f_2_11_va2 f_2_11_va2

	label variable f_2_12_va2 "I am sometimes irritated by people who ask favors of me."
	note f_2_12_va2: "I am sometimes irritated by people who ask favors of me."
	label define f_2_12_va2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values f_2_12_va2 f_2_12_va2

	label variable f_2_13_va2 "I have deliberately said something that hurt someone's feelings."
	note f_2_13_va2: "I have deliberately said something that hurt someone's feelings."
	label define f_2_13_va2 1 "Strongly disagree" 2 "Somewhat disagree" 3 "Neither disagree nor agree" 4 "Somewhat agree" 5 "Strongly agree"
	label values f_2_13_va2 f_2_13_va2

	label variable g_2_1 "Do you have an unfavorable or favorable view of the enumerator?"
	note g_2_1: "Do you have an unfavorable or favorable view of the enumerator?"
	label define g_2_1 1 "Very unfavorable" 2 "Somewhat unfavorable" 3 "Neither favorable nor unfavorable" 4 "Somewhat favorable" 5 "Strongly favorable"
	label values g_2_1 g_2_1

	label variable g_2_2 "Do you think the surveyor is unbiased or biased?"
	note g_2_2: "Do you think the surveyor is unbiased or biased?"
	label define g_2_2 1 "Strongly unbiased" 2 "Somewhat unbiased" 3 "Neither biased nor unbiased" 4 "Somewhat biased" 5 "Strongly biased"
	label values g_2_2 g_2_2

	label variable observation "TO ENUMERATOR: Please put any final remarks before submitting this entry."
	note observation: "TO ENUMERATOR: Please put any final remarks before submitting this entry."

	label variable a_4latitude "Please take the GPS coordinates of the table. (latitude)"
	note a_4latitude: "Please take the GPS coordinates of the table. (latitude)"

	label variable a_4longitude "Please take the GPS coordinates of the table. (longitude)"
	note a_4longitude: "Please take the GPS coordinates of the table. (longitude)"

	label variable a_4altitude "Please take the GPS coordinates of the table. (altitude)"
	note a_4altitude: "Please take the GPS coordinates of the table. (altitude)"

	label variable a_4accuracy "Please take the GPS coordinates of the table. (accuracy)"
	note a_4accuracy: "Please take the GPS coordinates of the table. (accuracy)"


	* append old, previously-imported data (if any)
	cap confirm file "`dtafile'"
	if _rc == 0 {
		* mark all new data before merging with old data
		gen new_data_row=1
		
		* pull in old data
		append using "`dtafile'"
		
		* drop duplicates in favor of old, previously-imported data if overwrite_old_data is 0
		* (alternatively drop in favor of new data if overwrite_old_data is 1)
		sort key
		by key: gen num_for_key = _N
		drop if num_for_key > 1 & ((`overwrite_old_data' == 0 & new_data_row == 1) | (`overwrite_old_data' == 1 & new_data_row ~= 1))
		drop num_for_key

		* drop new-data flag
		drop new_data_row
	}
	
	* make enumerator name a factor variable
	*tostring enum_2, replace
	*encode enum_2, generate(enum_2_num)
	
	* remove confidential information or unnecessary variables
	drop b_1 b_4 enum_3 a_3 
	drop deviceid username devicephonenum a5 consent 
	drop my_seed random1 random2 
	drop version1 version2_1 version2_2  version2_3 version2_4 version2_5
	drop g_2_1 g_2_2 observation formdef_version key 
	drop introduction1enum1enum_1 submissiondate
	
	*drop label of variable enum_2
	label drop enum_2
	
	*change restaurant names to A, B, C, and D
replace c0_1string = "Restaurant B" if c0_1string == "Restaurant Chez Françoise"
replace c0_1string = "Restaurant C" if c0_1string == "Restaurant La grâce"
replace c0_1string = "Restaurant D" if c0_1string == "Resto-Bar"
replace c0_1string = "Restaurant A" if c0_1string == "Restaurant Le Maxime"
	
	
	*change the geocoordinates
set seed 20231106
generate lat_adj = runiform() * 0.02
generate lon_adj = runiform() * 0.02
gen a_4latitude_adj  = a_4latitude + lat_adj
gen a_4longitude_adj  = a_4longitude + lon_adj

drop a_4latitude a_4longitude lat_adj lon_adj

rename (a_4latitude_adj a_4longitude_adj) (a_4latitude a_4longitude)


	* save data to Stata format
	save "`dtafile'", replace

	* show codebook and notes
	codebook
	notes list
}


disp
disp "Finished import of: `csvfile'"
disp

