rm(list = ls())

pacman::p_load("dplyr","readr",'lubridate','ggplot2','haven','readxl','purrr',"Formula", 
               'fixest', 'stringr', 'xtable')

#For making tables
formNum <- function(mynum, dig){
  
  roundcoef <- round(mynum, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundcoef))==0){
    roundcoef <- paste0(roundcoef, ".")
  }
  
  #Add an extra zero beyond the decimal point if needed to get same length
  #Only do if does not contain e- or e+ (scientific notation)
  if(grep("e",roundcoef) %>% length() == 0){
    roundcoef <- sapply(seq_len(length(roundcoef)), function(x){
      if(gsub(".*\\.","",roundcoef[x]) %>% nchar() < dig){
        #Needed length
        zerosneeded <- dig - gsub(".*\\.","",roundcoef[x]) %>% nchar()
        roundcoef[x] <- paste0(roundcoef[x],paste0(rep(0,zerosneeded),collapse=""))
      } else{
        roundcoef[x]
      }
    })
  }
  
  #Add commas if necessary
  roundcoef <- prettyNum(roundcoef, ",")
  
  return(roundcoef)
}

#Given se and number of digits to round to, 
#return formatted SE
formSE <- function(se, dig){
  
  #Round
  roundse <- round(se, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundse))==0){
    roundse <- paste0(roundse, ".")
  }
  
  #Add zeros if necessary
  roundse <- sapply(seq_len(length(roundse)), function(x){
    if(gsub(".*\\.","",roundse[x]) %>% nchar() < dig){
      #Needed length (could need one extra zero or two)
      zerosneeded <- dig - gsub(".*\\.","",roundse[x]) %>% nchar()
      roundse[x] <- paste0(roundse[x],paste0(rep(0,zerosneeded),collapse=""))
    } else{
      roundse[x]
    }
  })
  
  #Add commas if necessary
  roundse <- prettyNum(roundse, ",")
  
  #Add parentheses 
  roundse <- paste0("(",roundse,")")
  
  return(roundse)
}

#Given regression object, create formatted vector of coefficients and standard errors
formReg <- function(regobj, data, dig, depvar, fixedeffects){
  
  vec <- map(names(coefficients(regobj)), function(x){
    
    singlecoef <- formNum(coefficients(regobj)[x], dig)
    singlese <- formSE(se(regobj)[x], dig)
    c(singlecoef, singlese)
    
  }) %>% unlist()
  
  #Append to vec mean of dep var among control group, 
  #percent change treatment coefficient represents relative to this mean
  #and number of obs in regression
  controlmean <- filter(data, treated == 0) %>% pull(depvar) %>%
    mean()
  #were table and date fixed effects included in the regression?
  indfe <- ifelse(fixedeffects == 1, "Yes", "No")
  
  percentchange <- (coefficients(regobj)["treated"] / controlmean) * 100
  
  vec <- c(vec, indfe,
           regobj$nobs,
           #formNum(controlmean, dig), 
           formNum(percentchange, 2))
  
  return(vec)
}

#created in make_coupon_data.R
load('data/analysis_data/coupon_data.Rdata')

dat$start <- as.POSIXct(dat$starttime, format="%Y-%m-%d %H:%M:%S")
dat$end <- as.POSIXct(dat$endtime, format="%Y-%m-%d %H:%M:%S")

dat$diff_minutes <- as.numeric(difftime(dat$end, dat$start, units = "mins"))

controlvars <- "restaurant + days_bushmeat + age + male + university + educ_years + salary + business_owner | interview_date_fe + table_fe"

####################################################################################################
################################### REGRESSIONS WITH ALL OBSERVATIONS ##############################
####################################################################################################

#cluster at subject level because that is level of treatment assignment
reg_ordered_bushmeat_controls <- feols(as.Formula(paste0("bushmeat_in_dish ~ treated + ", controlvars)),
                                       data = dat, 
                                       cluster = 'coupon_id_gen')

#As point of comparison also regress without any control variables
reg_ordered_bushmeat_mean <- feols(bushmeat_in_dish ~ treated,
                                   data = dat, 
                                   cluster = 'coupon_id_gen')

##Second pre-specified regression is take-up  
reg_takeup_controls <- feols(as.Formula(paste0("takeup ~ treated + ", controlvars)),
                             data = dat, 
                             cluster = 'coupon_id_gen')

#As point of comparison also regress without any control variables
reg_takeup_mean <- feols(takeup ~ treated,
                         data = dat, 
                         cluster = 'coupon_id_gen')


tab <- matrix(NA, ncol =  5, nrow = 24)

tab[1,] <-  c("", "(1)", "(2)", "(3)", "(4)")

tab[2:24,1] <- c("Treatment", "", "Restaurant Habit", "", "Bushmeat Days", "", 
                 "Age", "", "Male", "", "University Graduate", "", "Years of Education", "", 
                 "Salary Earner", "", "Business Owner", "", "Intercept", "",
                 "Date and Table Fixed Effects", "N", "Percent Change")

tab[2:3,2] <- formReg(reg_ordered_bushmeat_mean, dat, 3, "bushmeat_in_dish", 0)[3:4]
tab[20:21,2] <- formReg(reg_ordered_bushmeat_mean, dat, 3, "bushmeat_in_dish", 0)[1:2]
tab[22:24,2] <- formReg(reg_ordered_bushmeat_mean, dat, 3, "bushmeat_in_dish", 0)[5:7]


tab[2:19,3] <- formReg(reg_ordered_bushmeat_controls, dat, 3, "bushmeat_in_dish", 1)[1:18]
tab[22:24,3] <- formReg(reg_ordered_bushmeat_controls, dat, 3, "bushmeat_in_dish", 1)[19:21]


tab[2:3,4] <- formReg(reg_takeup_mean, dat, 3, "takeup", 0)[3:4]
tab[20:21,4] <- formReg(reg_takeup_mean, dat, 3, "takeup", 0)[1:2]
tab[22:24,4] <- formReg(reg_takeup_mean, dat, 3, "takeup", 0)[5:7]


tab[2:19,5] <- formReg(reg_takeup_controls, dat, 3, "takeup", 1)[1:18]
tab[22:24,5] <- formReg(reg_takeup_controls, dat, 3, "takeup", 1)[19:21]

myxtable <- xtable(tab)

align(myxtable) <- c("l","l",rep("c",4))

label(myxtable) <- "mealchoices_takeup"

print(myxtable, floating = TRUE, caption.placement="top",sanitize.text.function = identity,
      include.colnames=FALSE, include.rownames=FALSE, table.placement="tb",
      hline.after=NULL,
      add.to.row=list(
        pos = list(0, 0, 1, 21, nrow(tab)),
        command = c(
          "\\toprule  & \\multicolumn{4}{c}{Dependent Variable:} \\\\",
          "\\cmidrule(lr){2-5} & \\multicolumn{2}{c}{Ordered Bushmeat}  & \\multicolumn{2}{c}{Used Coupon} \\\\  \\cmidrule(lr){2-3} \\cmidrule(lr){4-5}",
          "\\midrule ",
          "\\midrule ",
          "\\bottomrule "
        )),
      type = "latex", file="output/tables/table2.tex")

####################################################################################################
################################### REGRESSIONS WITH RESPONDENTS WITH LONG ENOUGH INTERVIEWS ##############################
####################################################################################################

dat2 <- dat %>%
  filter(diff_minutes >= 5)

#cluster at subject level because that is level of treatment assignment
reg_ordered_bushmeat_controls2 <- feols(as.Formula(paste0("bushmeat_in_dish ~ treated + ", controlvars)),
                                        data = dat2, 
                                        cluster = 'coupon_id_gen')

#As point of comparison also regress without any control variables
reg_ordered_bushmeat_mean2 <- feols(bushmeat_in_dish ~ treated,
                                    data = dat2, 
                                    cluster = 'coupon_id_gen')

##Second pre-specified regression is take-up  
reg_takeup_controls2 <- feols(as.Formula(paste0("takeup ~ treated + ", controlvars)),
                              data = dat2, 
                              cluster = 'coupon_id_gen')

#As point of comparison also regress without any control variables
reg_takeup_mean2 <- feols(takeup ~ treated,
                          data = dat2, 
                          cluster = 'coupon_id_gen')


tab2 <- matrix(NA, ncol =  5, nrow = 24)

tab2[1,] <-  c("", "(1)", "(2)", "(3)", "(4)")

tab2[2:24,1] <- c("Treatment", "", "Restaurant Habit", "", "Bushmeat Days", "", 
                  "Age", "", "Male", "", "University Graduate", "", "Years of Education", "", 
                  "Salary Earner", "", "Business Owner", "", "Intercept", "",
                  "Date and Table Fixed Effects", "N", "Percent Change")

tab2[2:3,2] <- formReg(reg_ordered_bushmeat_mean2, dat2, 3, "bushmeat_in_dish", 0)[3:4]
tab2[20:21,2] <- formReg(reg_ordered_bushmeat_mean2, dat2, 3, "bushmeat_in_dish", 0)[1:2]
tab2[22:24,2] <- formReg(reg_ordered_bushmeat_mean2, dat2, 3, "bushmeat_in_dish", 0)[5:7]


tab2[2:19,3] <- formReg(reg_ordered_bushmeat_controls2, dat2, 3, "bushmeat_in_dish", 1)[1:18]
tab2[22:24,3] <- formReg(reg_ordered_bushmeat_controls2, dat2, 3, "bushmeat_in_dish", 1)[19:21]


tab2[2:3,4] <- formReg(reg_takeup_mean2, dat2, 3, "takeup", 0)[3:4]
tab2[20:21,4] <- formReg(reg_takeup_mean2, dat2, 3, "takeup", 0)[1:2]
tab2[22:24,4] <- formReg(reg_takeup_mean2, dat2, 3, "takeup", 0)[5:7]


tab2[2:19,5] <- formReg(reg_takeup_controls2, dat2, 3, "takeup", 1)[1:18]
tab2[22:24,5] <- formReg(reg_takeup_controls2, dat2, 3, "takeup", 1)[19:21]

myxtable2 <- xtable(tab2)

align(myxtable2) <- c("l","l",rep("c",4))

label(myxtable2) <- "mealchoices_takeup2"

print(myxtable2, floating = TRUE, caption.placement="top",sanitize.text.function = identity,
      include.colnames=FALSE, include.rownames=FALSE, table.placement="tb",
      hline.after=NULL,
      add.to.row=list(
        pos = list(0, 0, 1, 21, nrow(tab2)),
        command = c(
          "\\toprule  & \\multicolumn{4}{c}{Dependent Variable:} \\\\",
          "\\cmidrule(lr){2-5} & \\multicolumn{2}{c}{Ordered Bushmeat}  & \\multicolumn{2}{c}{Used Coupon} \\\\  \\cmidrule(lr){2-3} \\cmidrule(lr){4-5}",
          "\\midrule ",
          "\\midrule ",
          "\\bottomrule "
        )),
      type = "latex", file="output/tables/mealchoices_takeup2.tex")
