rm(list = ls())

pacman::p_load("dplyr","readr",'lubridate','ggplot2','haven','readxl','purrr',"Formula", 
               'fixest', 'stringr','tidyr', 'xtable')

#For making tables
formNum <- function(mynum, dig){
  
  roundcoef <- round(mynum, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundcoef))==0){
    roundcoef <- paste0(roundcoef, ".")
  }
  
  #Add an extra zero beyond the decimal point if needed to get same length
  #Only do if does not contain e- or e+ (scientific notation)
  if(grep("e",roundcoef) %>% length() == 0){
    roundcoef <- sapply(seq_len(length(roundcoef)), function(x){
      if(gsub(".*\\.","",roundcoef[x]) %>% nchar() < dig){
        #Needed length
        zerosneeded <- dig - gsub(".*\\.","",roundcoef[x]) %>% nchar()
        roundcoef[x] <- paste0(roundcoef[x],paste0(rep(0,zerosneeded),collapse=""))
      } else{
        roundcoef[x]
      }
    })
  }
  
  #Add commas if necessary
  roundcoef <- prettyNum(roundcoef, ",")
  
  return(roundcoef)
}

#Given se and number of digits to round to, 
#return formatted SE
formSE <- function(se, dig){
  
  #Round
  roundse <- round(se, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundse))==0){
    roundse <- paste0(roundse, ".")
  }
  
  #Add zeros if necessary
  roundse <- sapply(seq_len(length(roundse)), function(x){
    if(gsub(".*\\.","",roundse[x]) %>% nchar() < dig){
      #Needed length (could need one extra zero or two)
      zerosneeded <- dig - gsub(".*\\.","",roundse[x]) %>% nchar()
      roundse[x] <- paste0(roundse[x],paste0(rep(0,zerosneeded),collapse=""))
    } else{
      roundse[x]
    }
  })
  
  #Add commas if necessary
  roundse <- prettyNum(roundse, ",")
  
  #Add parentheses 
  roundse <- paste0("(",roundse,")")
  
  return(roundse)
}

#Given regression object, create formatted vector of coefficients and standard errors
formReg <- function(regobj, dig){
  
  vec <- map(names(coefficients(regobj)), function(x){
    
    singlecoef <- formNum(coefficients(regobj)[x], dig)
    singlese <- formSE(se(regobj)[x], dig)
    c(singlecoef, singlese)
    
  }) %>% unlist()
  
  vec <- c(vec, 
           regobj$nobs)
  
  return(vec)
}

#Created in make_sales_data.R
load('data/analysis_data/sales_data.Rdata')

#log dishes sold and dish prices
sales <- mutate(sales, log_price_moambe_chicken = log(price_moambe_chicken), 
                log_price_bushmeat = log(price_bushmeat), 
                log_number_sold_moambe_chicken = log(number_sold_moambe_chicken),
                log_number_sold_bushmeat = log(number_sold_bushmeat))

#2SLS
crosselast <- feols(log_number_sold_bushmeat ~ Q0 + P0 | log_price_moambe_chicken ~ treated, 
                    data = sales, 
                    cluster = ~restaurant^date)
summary(crosselast)

#manual first stage
firststage <- feols(log_price_moambe_chicken ~ treated + Q0 + P0, data = sales, 
                    cluster = ~restaurant^date) 

#manual reduced form
reducedform <- feols(log_number_sold_bushmeat ~ treated + Q0 + P0, data = sales, 
                     cluster = ~restaurant^date) 
#would have expected positive treated coefficient

#What about moambe chicken own price elasticity?
ownelast <- feols(log_number_sold_moambe_chicken ~ Q0 + P0 | log_price_moambe_chicken ~ treated, 
                  data = sales, 
                  cluster = ~restaurant^date) 

#manual reduced form
ownreducedform <- feols(log_number_sold_moambe_chicken ~ treated + Q0 + P0, data = sales, 
                        cluster = ~restaurant^date)
#this is as expected

tab <- matrix(NA, nrow = 13, ncol = 6)

tab[1,] <- c("", "Log Price", "Log Dishes", "Log Dishes", "Log Dishes", "Log Dishes")
tab[2,] <- c("", "(1)", "(2)", "(3)", "(4)", "(5)")

tab[,1] <- c("", "", "Price Reduction Treatment", "", "Log Chicken Price", "", "Baseline Bushmeat Dishes", "", 
             "Baseline Average Price", "", "Intercept", "", "N")

tab[3:11,2] <- formReg(firststage, 3)
tab[3:11,3] <- formReg(ownreducedform, 3)
tab[3:11,4] <- formReg(ownelast, 3)
tab[3:11,5] <- formReg(reducedform, 3)
tab[3:11,6] <- formReg(crosselast, 3)

#Move N down
tab[13, 2:6] <- tab[11, 2:6]

#Move intercept down
tab[11:12, 2:6] <- tab[3:4, 2:6]

#move treatment up non-elasticity regressions 
tab[3:4, c(2, 3, 5)] <- tab[5:6, c(2, 3, 5)]

#and blank out elasticity rows for these regressions
tab[5:6, c(2, 3, 5)] <- ""

#blank out treatment rows for elasticity regressions
tab[3:4, c(4, 6)] <- ""

myxtable <- xtable(tab)

align(myxtable) <- c("l","l",rep("c",5))

label(myxtable) <- "elasticity_tab"

print(myxtable, floating = TRUE, caption.placement="top",sanitize.text.function = identity,
      include.colnames=FALSE, include.rownames=FALSE, table.placement="tb",
      hline.after=NULL,
      add.to.row=list(
        pos = list(0, 0, 2, 12, nrow(tab)),
        command = c(
          "\\toprule & \\multicolumn{3}{c}{Moambe Chicken}  & \\multicolumn{2}{c}{Bushmeat} \\\\  \\cmidrule(lr){2-4} \\cmidrule(lr){5-6} ",
          "& \\multicolumn{3}{c}{Dependent Variable:}  & \\multicolumn{2}{c}{Dependent Variable:} \\\\ ",
          "\\midrule ",
          "\\midrule ",
          "\\bottomrule "
        )),
      type = "latex",file="output/tables/table3.tex")
