rm(list = ls())

options(scipen = 999)

pacman::p_load("dplyr","readr",'lubridate','ggplot2','haven','readxl','purrr',"Formula", 
               'fixest', 'stringr', 'xtable', 'sf', 'geosphere')

#For making tables
formNum <- function(mynum, dig){
  
  roundcoef <- round(mynum, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundcoef))==0){
    roundcoef <- paste0(roundcoef, ".")
  }
  
  #Add an extra zero beyond the decimal point if needed to get same length
  #Only do if does not contain e- or e+ (scientific notation)
  if(grep("e",roundcoef) %>% length() == 0){
    roundcoef <- sapply(seq_len(length(roundcoef)), function(x){
      if(gsub(".*\\.","",roundcoef[x]) %>% nchar() < dig){
        #Needed length
        zerosneeded <- dig - gsub(".*\\.","",roundcoef[x]) %>% nchar()
        roundcoef[x] <- paste0(roundcoef[x],paste0(rep(0,zerosneeded),collapse=""))
      } else{
        roundcoef[x]
      }
    })
  }
  
  #Add commas if necessary
  roundcoef <- prettyNum(roundcoef, ",")
  
  return(roundcoef)
}

#Given se and number of digits to round to, 
#return formatted SE
formSE <- function(se, dig){
  
  #Round
  roundse <- round(se, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundse))==0){
    roundse <- paste0(roundse, ".")
  }
  
  #Add zeros if necessary
  roundse <- sapply(seq_len(length(roundse)), function(x){
    if(gsub(".*\\.","",roundse[x]) %>% nchar() < dig){
      #Needed length (could need one extra zero or two)
      zerosneeded <- dig - gsub(".*\\.","",roundse[x]) %>% nchar()
      roundse[x] <- paste0(roundse[x],paste0(rep(0,zerosneeded),collapse=""))
    } else{
      roundse[x]
    }
  })
  
  #Add commas if necessary
  roundse <- prettyNum(roundse, ",")
  
  #Add parentheses 
  roundse <- paste0("(",roundse,")")
  
  return(roundse)
}

#Given regression object, create formatted vector of coefficients and standard errors
formReg <- function(regobj, dig, depvar, fixedeffects){
  
  vec <- map(names(coefficients(regobj)), function(x){
    
    singlecoef <- formNum(coefficients(regobj)[x], dig)
    singlese <- formSE(se(regobj)[x], dig)
    c(singlecoef, singlese)
    
  }) %>% unlist()
  
  #Append to vec mean of dep var among control group, 
  #percent change treatment coefficient represents relative to this mean
  #and number of obs in regression
  controlmean <- filter(dat, treated == 0) %>% pull(depvar) %>%
    mean()
  #were table and date fixed effects included in the regression?
  indfe <- ifelse(fixedeffects == 1, "Yes", "No")
  
  percentchange <- (coefficients(regobj)["treated"] / controlmean) * 100
  
  vec <- c(vec, indfe,
           regobj$nobs,
           #formNum(controlmean, dig), 
           formNum(percentchange, 2))
  
  return(vec)
}

#created in make_coupon_data.R
load('data/analysis_data/coupon_data.Rdata')

controlvars <- "restaurant + days_bushmeat + age + male + university + educ_years + salary + business_owner | interview_date_fe + table_fe"

##Third pre-specified regression is extensive margin choice of restaurant

#Construct dependent variable for regression: indicator for whether restaurant has above median bushmeat dishes
#on sample menus shown to subjects
bushmeatdishes <- rbind(c("Restaurant A", "2", "26"),
      c("Restaurant C", "4", "15"),
      c("Restaurant B", "3", "30"), 
      c("Restaurant D", "5", "17")
) %>% as.data.frame() %>% as_tibble()

names(bushmeatdishes) <- c("c0_1string", "bushmeatdishes", "nonbushmeatdishes")

bushmeatdishes <- mutate(bushmeatdishes, bushmeatdishes = as.numeric(bushmeatdishes), 
                         nonbushmeatdishes = as.numeric(nonbushmeatdishes)) %>% 
  mutate(bushmeatprop = bushmeatdishes / (bushmeatdishes + nonbushmeatdishes)) %>% 
  arrange(desc(bushmeatprop))

bushmeatdishes$bushmeatrestaurant <- c(1, 1, 0, 0)

bushmeatdishes <- select(bushmeatdishes, c0_1string, bushmeatrestaurant)

#join onto dat
dat <- left_join(dat, bushmeatdishes, by = "c0_1string")

#restaurant coordinates
coords <- read_dta('data/raw_data/restaurants_gps_ano.dta')

dat <- left_join(dat, 
                 select(coords, c0_1string, a_4latitude, a_4longitude) %>%
                   rename(rest_a_4latitude = a_4latitude, rest_a_4longitude = a_4longitude), 
                 by = 'c0_1string')

dat <- mutate(dat, dist_to_rest_m = distHaversine(select(dat, a_4longitude, a_4latitude) %>% as.matrix(), 
              select(dat, rest_a_4longitude, rest_a_4latitude) %>% as.matrix()))

#Created in make_sales_data.R
load('data/analysis_data/sales_data.Rdata')

dat <- left_join(dat, 
                 select(sales, restaurant, P0) %>% 
                   rename(c0_1string = restaurant) %>% distinct() %>% 
                   mutate(c0_1string = case_when(
                     c0_1string == "Restaurant B" ~ "Restaurant B", 
                     c0_1string == "Restaurant C" ~ "Restaurant C", 
                     c0_1string == "Restaurant D" ~ "Restaurant D", 
                     TRUE ~ c0_1string
                   )), 
                 by = 'c0_1string')

#distance in km so digits more visible
dat <- rename(dat, dist_to_rest_km = dist_to_rest_m) %>% 
  mutate(dist_to_rest_km = dist_to_rest_km / 1000)

ext_controls <- feols(as.Formula(paste0("bushmeatrestaurant ~ treated + dist_to_rest_km + P0 + ", controlvars)),
                             data = dat, 
                             cluster = 'coupon_id_gen')

ext_mean <- feols(bushmeatrestaurant ~ treated, data = dat, cluster = 'coupon_id_gen')


tab <- matrix(NA, ncol =  3, nrow = 28)

tab[1,] <-  c("", "(1)", "(2)")

tab[2:28,1] <- c("Treatment", "", "Distance to Restaurant", "", "Baseline Average Price", "", 
                 "Restaurant Habit", "", "Bushmeat Days", "", 
                 "Age", "", "Male", "", "University Graduate", "", "Years of Education", "", 
                 "Salary Earner", "", "Business Owner", "", "Intercept", "",
                 "Date and Table Fixed Effects", "N",  "Percent Change")

tab[2:3,2] <- formReg(ext_mean, 3, "bushmeatrestaurant", 0)[3:4]
tab[24:25,2] <- formReg(ext_mean, 3, "bushmeatrestaurant", 0)[1:2]
tab[26:28,2] <- formReg(ext_mean, 3, "bushmeatrestaurant", 0)[5:7]


tab[2:23,3] <- formReg(ext_controls, 4, "bushmeatrestaurant", 1)[1:22]
tab[26:28,3] <- formReg(ext_controls, 4, "bushmeatrestaurant", 1)[23:25]

myxtable <- xtable(tab)

align(myxtable) <- c("l","l",rep("c",2))

label(myxtable) <- "extensive_margin"

print(myxtable, floating = TRUE, caption.placement="top",sanitize.text.function = identity,
      include.colnames=FALSE, include.rownames=FALSE, table.placement="tb",
      hline.after=NULL,
      add.to.row=list(
        pos = list(0, 1, 25, nrow(tab)),
        command = c(
          "\\toprule ",
          "\\midrule ",
          "\\midrule ",
          "\\bottomrule "
        )),
      type = "latex",file="output/tables/table_s1.tex")

