rm(list = ls())

pacman::p_load("dplyr","readr",'lubridate','ggplot2','haven','readxl','purrr',"Formula", 
               'fixest', 'stringr', 'xtable')

#For making tables
formNum <- function(mynum, dig){
  
  roundcoef <- round(mynum, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundcoef))==0){
    roundcoef <- paste0(roundcoef, ".")
  }
  
  #Add an extra zero beyond the decimal point if needed to get same length
  #Only do if does not contain e- or e+ (scientific notation)
  if(grep("e",roundcoef) %>% length() == 0){
    roundcoef <- sapply(seq_len(length(roundcoef)), function(x){
      if(gsub(".*\\.","",roundcoef[x]) %>% nchar() < dig){
        #Needed length
        zerosneeded <- dig - gsub(".*\\.","",roundcoef[x]) %>% nchar()
        roundcoef[x] <- paste0(roundcoef[x],paste0(rep(0,zerosneeded),collapse=""))
      } else{
        roundcoef[x]
      }
    })
  }
  
  #Add commas if necessary
  roundcoef <- prettyNum(roundcoef, ",")
  
  return(roundcoef)
}

#Given se and number of digits to round to, 
#return formatted SE
formSE <- function(se, dig){
  
  #Round
  roundse <- round(se, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundse))==0){
    roundse <- paste0(roundse, ".")
  }
  
  #Add zeros if necessary
  roundse <- sapply(seq_len(length(roundse)), function(x){
    if(gsub(".*\\.","",roundse[x]) %>% nchar() < dig){
      #Needed length (could need one extra zero or two)
      zerosneeded <- dig - gsub(".*\\.","",roundse[x]) %>% nchar()
      roundse[x] <- paste0(roundse[x],paste0(rep(0,zerosneeded),collapse=""))
    } else{
      roundse[x]
    }
  })
  
  #Add commas if necessary
  roundse <- prettyNum(roundse, ",")
  
  #Add parentheses 
  roundse <- paste0("(",roundse,")")
  
  return(roundse)
}

#Given regression object, create formatted vector of coefficients and standard errors
formReg <- function(regobj, dig, depvar, fixedeffects){
  
  vec <- map(names(coefficients(regobj)), function(x){
    
    singlecoef <- formNum(coefficients(regobj)[x], dig)
    singlese <- formSE(se(regobj)[x], dig)
    c(singlecoef, singlese)
    
  }) %>% unlist()
  
  #Append to vec mean of dep var among control group, 
  #percent change treatment coefficient represents relative to this mean
  #and number of obs in regression
  controlmean <- filter(dat, treated == 0) %>% pull(depvar) %>%
    mean()
  #were table and date fixed effects included in the regression?
  indfe <- ifelse(fixedeffects == 1, "Yes", "No")
  
  percentchange <- (coefficients(regobj)["treated"] / controlmean) * 100
  
  vec <- c(vec, indfe,
           regobj$nobs,
           #formNum(controlmean, dig), 
           formNum(percentchange, 2))
  
  return(vec)
}

#created in make_coupon_data.R
load('data/analysis_data/coupon_data.Rdata')

controlvars <- "restaurant + days_bushmeat + age + male + university + educ_years + salary + business_owner | interview_date_fe + table_fe"

##Fourth pre-specified regression and fifth set are mechanisms

#Extract attributes of variables beginning with D; these are six view of bushmeat questions (60 total)
bushcols <- grep("^d[0-9]", names(dat), value = TRUE)

#6 variables to fill values
fillat <- data.frame(tasty = as.numeric(NA), sustainable = as.numeric(NA),
                     healthy = as.numeric(NA), fresh = as.numeric(NA), 
                     cool = as.numeric(NA), legal = as.numeric(NA))

dat <- bind_cols(dat, fillat)

# Function to check if word is in the text
check_word_in_text <- function(text, word) {
  str_detect(text, fixed(word))
}

for(i in bushcols){
  
  #attributes of this column
  myat <- pull(dat, i) %>% attributes()
  
  #which variable is this
  whichvar <- sapply(1:length(fillat), function(x){
    check_word_in_text(myat$label, names(fillat)[x])
  })
  
  fillvar <- names(fillat)[which(whichvar == TRUE)]
  
  #Which responses to this question indicate an unfavorable view
  whichunf <- grep("disagree", names(myat$labels))
  
  #3 is always neither, so ignore that one
  whichunf <- whichunf[-which(whichunf == 3)]
  
  #favorable or neither values
  whichfav <- setdiff(1:5, whichunf)
  
  #can now drop attributes
  dat[, i] <- pull(dat, i) %>% as.numeric()
  
  #favorable view is 0
  dat[which(!is.na(pull(dat, i)) & pull(dat, i) %in% whichfav), i] <- 0
  
  #unfavorable view is 1
  dat[which(!is.na(pull(dat, i)) & pull(dat, i) %in% whichunf), i] <- 1
  
  #now fill these values in appropriate single column
  dat[which(!is.na(pull(dat, i))), which(names(dat) == fillvar)] <- 
    dat[which(!is.na(pull(dat, i))), i]
  
}

#Clean up
rm(myat, i, whichfav, whichunf, whichvar, fillvar, bushcols, fillat)

#E_1_1 agree and E_2_1 disagree connect to origin
dat$origin <- 0

dat$origin[which(!is.na(dat$e_1_1) & dat$e_1_1 %in% c(4,5))] <- 1
dat$origin[which(!is.na(dat$e_2_1) & dat$e_2_1 %in% c(1, 2))] <- 1

#F_1_0 and F_1_0_va2 proud of DRC environment (opinion 0)
dat$proud <- 0

dat$proud[which(!is.na(dat$f_1_0) & dat$f_1_0 %in% c(1, 2))] <- 1
dat$proud[which(!is.na(dat$f_1_0_va2) & dat$f_1_0_va2 %in% c(1, 2))] <- 1

#Calculate single standardized score
dat <- mutate(dat, unfav_score = tasty + sustainable + 
                healthy +  fresh + cool +  legal + origin + proud)

dat <- mutate(dat, unfav_score = (unfav_score - mean(dat$unfav_score)) / 
                sd(dat$unfav_score))

#Format regression displaying only treatment coefficient
formHorizReg <- function(regobj, dig, depvar, depvarlabel){
  
  coef <- formNum(regobj$coeftable["treated","Estimate"], dig)
  se <- formSE(regobj$coeftable["treated","Std. Error"], dig)
  controlmean <- filter(dat, treated == 0) %>% pull(depvar) %>%
    mean() %>% formNum(dig)
  N <- regobj$nobs
  
  out <- c(depvarlabel, coef, se, controlmean, N)
  
  return(out)
}


#Now one regression for each individual component of the unfavorable view of bushmeat score
tab <- matrix(NA, ncol = 5, nrow = 10)

tab[1,] <- c("Dependent Variable", "Treatment Coefficient", "Treatment Standard Error", "Control Mean", "N")

tab[2, ] <- formHorizReg(paste0("unfav_score ~ treated + ", controlvars) %>% as.Formula() %>% 
                           feols(data = dat, cluster = 'coupon_id_gen'), 
                        3, "unfav_score", "Unfavorable")
#Positive coefficent would mean treatment worsened view of bushmeat

tab[3, ] <- formHorizReg(paste0("tasty ~ treated + ", controlvars) %>% as.Formula() %>% 
                           feols(data = dat, cluster = 'coupon_id_gen'), 
                         3, "tasty", "Tasty")

tab[4, ] <- formHorizReg(paste0("sustainable ~ treated + ", controlvars) %>% as.Formula() %>% 
                           feols(data = dat, cluster = 'coupon_id_gen'), 
                         3, "sustainable", "Sustainable")

tab[5, ] <- formHorizReg(paste0("healthy ~ treated + ", controlvars) %>% as.Formula() %>% 
                           feols(data = dat, cluster = 'coupon_id_gen'), 
                         3, "healthy", "Healthy")

tab[6, ] <- formHorizReg(paste0("fresh ~ treated + ", controlvars) %>% as.Formula() %>% 
                           feols(data = dat, cluster = 'coupon_id_gen'), 
                         3, "fresh", "Fresh")

tab[7, ] <- formHorizReg(paste0("cool ~ treated + ", controlvars) %>% as.Formula() %>% 
                           feols(data = dat, cluster = 'coupon_id_gen'), 
                         3, "cool", "Cool")

tab[8, ] <- formHorizReg(paste0("legal ~ treated + ", controlvars) %>% as.Formula() %>% 
                           feols(data = dat, cluster = 'coupon_id_gen'), 
                         3, "legal", "Legal")

tab[9, ] <- formHorizReg(paste0("origin ~ treated + ", controlvars) %>% as.Formula() %>% 
                           feols(data = dat, cluster = 'coupon_id_gen'), 
                         3, "origin", "Origin")

tab[10, ] <- formHorizReg(paste0("proud ~ treated + ", controlvars) %>% as.Formula() %>% 
                            feols(data = dat, cluster = 'coupon_id_gen'), 
                          3, "proud", "Proud")


myxtable <- xtable(tab)

align(myxtable) <- c("l","l",rep("c",4))

label(myxtable) <- "mechanism_table"

print(myxtable, floating = TRUE, caption.placement="top",sanitize.text.function = identity,
      include.colnames=FALSE, include.rownames=FALSE, table.placement="tb",
      hline.after=NULL,
      add.to.row=list(
        pos = list(0, 1, nrow(tab)),
        command = c(
          "\\toprule ",
          "\\midrule ", 
          "\\bottomrule "
        )),
      type = "latex", file="output/tables/table_s2.tex")
